netapp_ontap.models.ems_filter_rules_message_criteria API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.ems_filter_rules_message_criteria`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class EmsFilterRulesMessageCriteriaSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the EmsFilterRulesMessageCriteria object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `links: RelatedLink GET`

    The links field of the ems_filter_rules_message_criteria.

  `name_pattern: str GET POST PATCH`

    Message name filter on which to match. Supports wildcards. Defaults to * if not specified.

    Example: wafl.*

  `severities: str GET POST PATCH`

    A comma-separated list of severities or a wildcard.

    Example: emergency,alert,error

  `snmp_trap_types: str GET POST PATCH`

    A comma separated list of snmp_trap_types or a wildcard.

    Example: standard,built_in